@@ -10,6 +10,7 @@ import (
 	"strings"
 	"time"
 
+	"github.com/atotto/clipboard"
 	"github.com/go-rod/rod/lib/input"
 	"github.com/mattn/go-runewidth"
 )
@@ -20,6 +21,8 @@ type CommandType TokenType
 // CommandTypes is a list of the available commands that can be executed.
 var CommandTypes = []CommandType{ //nolint: deadcode
 	BACKSPACE,
+	DELETE,
+	INSERT,
 	CTRL,
 	ALT,
 	DOWN,
@@ -41,6 +44,9 @@ var CommandTypes = []CommandType{ //nolint: deadcode
 	TYPE,
 	UP,
 	SOURCE,
+	SCREENSHOT,
+	COPY,
+	PASTE,
 }
 
 // String returns the string representation of the command.
@@ -58,27 +64,33 @@ type CommandFunc func(c Command, v *VHS)
 
 // CommandFuncs maps command types to their executable functions.
 var CommandFuncs = map[CommandType]CommandFunc{
-	BACKSPACE: ExecuteKey(input.Backspace),
-	DOWN:      ExecuteKey(input.ArrowDown),
-	ENTER:     ExecuteKey(input.Enter),
-	LEFT:      ExecuteKey(input.ArrowLeft),
-	RIGHT:     ExecuteKey(input.ArrowRight),
-	SPACE:     ExecuteKey(input.Space),
-	UP:        ExecuteKey(input.ArrowUp),
-	TAB:       ExecuteKey(input.Tab),
-	ESCAPE:    ExecuteKey(input.Escape),
-	PAGEUP:    ExecuteKey(input.PageUp),
-	PAGEDOWN:  ExecuteKey(input.PageDown),
-	HIDE:      ExecuteHide,
-	REQUIRE:   ExecuteRequire,
-	SHOW:      ExecuteShow,
-	SET:       ExecuteSet,
-	OUTPUT:    ExecuteOutput,
-	SLEEP:     ExecuteSleep,
-	TYPE:      ExecuteType,
-	CTRL:      ExecuteCtrl,
-	ALT:       ExecuteAlt,
-	ILLEGAL:   ExecuteNoop,
+	BACKSPACE:  ExecuteKey(input.Backspace),
+	DELETE:     ExecuteKey(input.Delete),
+	INSERT:     ExecuteKey(input.Insert),
+	DOWN:       ExecuteKey(input.ArrowDown),
+	ENTER:      ExecuteKey(input.Enter),
+	LEFT:       ExecuteKey(input.ArrowLeft),
+	RIGHT:      ExecuteKey(input.ArrowRight),
+	SPACE:      ExecuteKey(input.Space),
+	UP:         ExecuteKey(input.ArrowUp),
+	TAB:        ExecuteKey(input.Tab),
+	ESCAPE:     ExecuteKey(input.Escape),
+	PAGEUP:     ExecuteKey(input.PageUp),
+	PAGEDOWN:   ExecuteKey(input.PageDown),
+	HIDE:       ExecuteHide,
+	REQUIRE:    ExecuteRequire,
+	SHOW:       ExecuteShow,
+	SET:        ExecuteSet,
+	OUTPUT:     ExecuteOutput,
+	SLEEP:      ExecuteSleep,
+	TYPE:       ExecuteType,
+	CTRL:       ExecuteCtrl,
+	ALT:        ExecuteAlt,
+	SHIFT:      ExecuteShift,
+	ILLEGAL:    ExecuteNoop,
+	SCREENSHOT: ExecuteScreenshot,
+	COPY:       ExecuteCopy,
+	PASTE:      ExecutePaste,
 }
 
 // Command represents a command with options and arguments.
@@ -153,6 +165,12 @@ func ExecuteCtrl(c Command, v *VHS) {
 			inputKey = &input.ShiftLeft
 		case "Alt":
 			inputKey = &input.AltLeft
+		case "Enter":
+			inputKey = &input.Enter
+		case "Space":
+			inputKey = &input.Space
+		case "Backspace":
+			inputKey = &input.Backspace
 		default:
 			r := rune(key[0])
 			if k, ok := keymap[r]; ok {
@@ -182,6 +200,30 @@ func ExecuteAlt(c Command, v *VHS) {
 		switch k {
 		case ENTER:
 			_ = v.Page.Keyboard.Type(input.Enter)
+		case TAB:
+			_ = v.Page.Keyboard.Type(input.Tab)
+		}
+	} else {
+		for _, r := range c.Args {
+			if k, ok := keymap[r]; ok {
+				_ = v.Page.Keyboard.Type(k)
+			}
+		}
+	}
+
+	_ = v.Page.Keyboard.Release(input.AltLeft)
+}
+
+// ExecuteShift is a CommandFunc that presses the argument key with the shift
+// key held down on the running instance of vhs.
+func ExecuteShift(c Command, v *VHS) {
+	_ = v.Page.Keyboard.Press(input.ShiftLeft)
+	if k, ok := keywords[c.Args]; ok {
+		switch k {
+		case ENTER:
+			_ = v.Page.Keyboard.Type(input.Enter)
+		case TAB:
+			_ = v.Page.Keyboard.Type(input.Tab)
 		}
 	} else {
 		for _, r := range c.Args {
@@ -257,6 +299,28 @@ func ExecuteOutput(c Command, v *VHS) {
 	}
 }
 
+// ExecuteCopy copies text to the clipboard.
+func ExecuteCopy(c Command, _ *VHS) {
+	_ = clipboard.WriteAll(c.Args)
+}
+
+// ExecutePaste pastes text from the clipboard.
+func ExecutePaste(_ Command, v *VHS) {
+	clip, err := clipboard.ReadAll()
+	if err != nil {
+		return
+	}
+	for _, r := range clip {
+		k, ok := keymap[r]
+		if ok {
+			_ = v.Page.Keyboard.Type(k)
+		} else {
+			_ = v.Page.MustElement("textarea").Input(string(r))
+			v.Page.MustWaitIdle()
+		}
+	}
+}
+
 // Settings maps the Set commands to their respective functions.
 var Settings = map[string]CommandFunc{
 	"FontFamily":    ExecuteSetFontFamily,
@@ -307,12 +371,12 @@ func ExecuteSetFontFamily(c Command, v *VHS) {
 
 // ExecuteSetHeight applies the height on the vhs.
 func ExecuteSetHeight(c Command, v *VHS) {
-	v.Options.Video.Height, _ = strconv.Atoi(c.Args)
+	v.Options.Video.Style.Height, _ = strconv.Atoi(c.Args)
 }
 
 // ExecuteSetWidth applies the width on the vhs.
 func ExecuteSetWidth(c Command, v *VHS) {
-	v.Options.Video.Width, _ = strconv.Atoi(c.Args)
+	v.Options.Video.Style.Width, _ = strconv.Atoi(c.Args)
 }
 
 // ExecuteSetShell applies the shell on the vhs.
@@ -353,8 +417,8 @@ func ExecuteSetTheme(c Command, v *VHS) {
 
 	bts, _ := json.Marshal(v.Options.Theme)
 	_, _ = v.Page.Eval(fmt.Sprintf("() => term.options.theme = %s", string(bts)))
-	v.Options.Video.BackgroundColor = v.Options.Theme.Background
-	v.Options.Video.WindowBarColor = v.Options.Theme.Background
+	v.Options.Video.Style.BackgroundColor = v.Options.Theme.Background
+	v.Options.Video.Style.WindowBarColor = v.Options.Theme.Background
 }
 
 // ExecuteSetTypingSpeed applies the default typing speed on the vhs.
@@ -368,7 +432,7 @@ func ExecuteSetTypingSpeed(c Command, v *VHS) {
 
 // ExecuteSetPadding applies the padding on the vhs.
 func ExecuteSetPadding(c Command, v *VHS) {
-	v.Options.Video.Padding, _ = strconv.Atoi(c.Args)
+	v.Options.Video.Style.Padding, _ = strconv.Atoi(c.Args)
 }
 
 // ExecuteSetFramerate applies the framerate on the vhs.
@@ -400,27 +464,27 @@ func ExecuteLoopOffset(c Command, v *VHS) {
 
 // ExecuteSetMarginFill sets vhs margin fill
 func ExecuteSetMarginFill(c Command, v *VHS) {
-	v.Options.Video.MarginFill = c.Args
+	v.Options.Video.Style.MarginFill = c.Args
 }
 
 // ExecuteSetMargin sets vhs margin size
 func ExecuteSetMargin(c Command, v *VHS) {
-	v.Options.Video.Margin, _ = strconv.Atoi(c.Args)
+	v.Options.Video.Style.Margin, _ = strconv.Atoi(c.Args)
 }
 
 // ExecuteSetWindowBar sets window bar type
 func ExecuteSetWindowBar(c Command, v *VHS) {
-	v.Options.Video.WindowBar = c.Args
+	v.Options.Video.Style.WindowBar = c.Args
 }
 
 // ExecuteSetWindowBar sets window bar size
 func ExecuteSetWindowBarSize(c Command, v *VHS) {
-	v.Options.Video.WindowBarSize, _ = strconv.Atoi(c.Args)
+	v.Options.Video.Style.WindowBarSize, _ = strconv.Atoi(c.Args)
 }
 
 // ExecuteSetWindowBar sets corner radius
 func ExecuteSetBorderRadius(c Command, v *VHS) {
-	v.Options.Video.BorderRadius, _ = strconv.Atoi(c.Args)
+	v.Options.Video.Style.BorderRadius, _ = strconv.Atoi(c.Args)
 }
 
 // ExecuteSetCursorBlink sets cursor blinking
@@ -478,6 +542,11 @@ func ExecuteSourceTape(c Command, v *VHS) {
 	}
 }
 
+// ExecuteScreenshot is a CommandFunc that indicates a new screenshot must be taken.
+func ExecuteScreenshot(c Command, v *VHS) {
+	v.ScreenshotNextFrame(c.Args)
+}
+
 func getTheme(s string) (Theme, error) {
 	if strings.TrimSpace(s) == "" {
 		return DefaultTheme, nil
