@@ -188,6 +188,20 @@ func TestLexTapeFile(t *testing.T) {
 		{AT, "@"},
 		{NUMBER, "1"},
 		{NUMBER, "3"},
+		{DELETE, "Delete"},
+		{DELETE, "Delete"},
+		{NUMBER, "2"},
+		{DELETE, "Delete"},
+		{AT, "@"},
+		{NUMBER, "1"},
+		{NUMBER, "3"},
+		{INSERT, "Insert"},
+		{INSERT, "Insert"},
+		{NUMBER, "2"},
+		{INSERT, "Insert"},
+		{AT, "@"},
+		{NUMBER, "1"},
+		{NUMBER, "3"},
 		{DOWN, "Down"},
 		{DOWN, "Down"},
 		{NUMBER, "2"},
