@@ -47,7 +47,7 @@ func (p *Parser) Parse() []Command {
 // parseCommand parses a command.
 func (p *Parser) parseCommand() Command {
 	switch p.cur.Type {
-	case SPACE, BACKSPACE, ENTER, ESCAPE, TAB, DOWN, LEFT, RIGHT, UP, PAGEUP, PAGEDOWN:
+	case SPACE, BACKSPACE, DELETE, INSERT, ENTER, ESCAPE, TAB, DOWN, LEFT, RIGHT, UP, PAGEUP, PAGEDOWN:
 		return p.parseKeypress(p.cur.Type)
 	case SET:
 		return p.parseSet()
@@ -61,6 +61,8 @@ func (p *Parser) parseCommand() Command {
 		return p.parseCtrl()
 	case ALT:
 		return p.parseAlt()
+	case SHIFT:
+		return p.parseShift()
 	case HIDE:
 		return p.parseHide()
 	case REQUIRE:
@@ -69,6 +71,12 @@ func (p *Parser) parseCommand() Command {
 		return p.parseShow()
 	case SOURCE:
 		return p.parseSource()
+	case SCREENSHOT:
+		return p.parseScreenshot()
+	case COPY:
+		return p.parseCopy()
+	case PASTE:
+		return p.parsePaste()
 	default:
 		p.errors = append(p.errors, NewError(p.cur, "Invalid command: "+p.cur.Literal))
 		return Command{Type: ILLEGAL}
@@ -139,31 +147,42 @@ func (p *Parser) parseTime() string {
 func (p *Parser) parseCtrl() Command {
 	var args []string
 
+	inModifierChain := true
 	for p.peek.Type == PLUS {
 		p.nextToken()
 		peek := p.peek
 
 		// Get key from keywords and check if it's a valid modifier
-		if k, ok := keywords[peek.Literal]; ok {
-			p.nextToken()
-			if IsModifier(k) {
-				args = append(args, peek.Literal)
-			} else {
-				p.errors = append(p.errors, NewError(p.cur, "not a valid modifier"))
+		if k := keywords[peek.Literal]; IsModifier(k) {
+			if !inModifierChain {
+				p.errors = append(p.errors, NewError(p.cur, "Modifiers must come before other characters"))
+				// Clear args so the error is returned
+				args = nil
+				continue
 			}
-		}
 
-		// Add key argument
-		if peek.Type == STRING && len(peek.Literal) == 1 {
-			p.nextToken()
 			args = append(args, peek.Literal)
+			p.nextToken()
+			continue
 		}
 
-		// Key arguments with len > 1 are not valid
-		if peek.Type == STRING && len(peek.Literal) > 1 {
-			p.nextToken()
-			p.errors = append(p.errors, NewError(p.cur, "Invalid control argument: "+p.cur.Literal))
+		inModifierChain = false
+
+		// Add key argument.
+		switch {
+		case peek.Type == ENTER,
+			peek.Type == SPACE,
+			peek.Type == BACKSPACE,
+			peek.Type == STRING && len(peek.Literal) == 1:
+			args = append(args, peek.Literal)
+		default:
+			// Key arguments with len > 1 are not valid
+			p.errors = append(p.errors,
+				NewError(p.cur, "Not a valid modifier"),
+				NewError(p.cur, "Invalid control argument: "+p.cur.Literal))
 		}
+
+		p.nextToken()
 	}
 
 	if len(args) == 0 {
@@ -181,7 +200,7 @@ func (p *Parser) parseCtrl() Command {
 func (p *Parser) parseAlt() Command {
 	if p.peek.Type == PLUS {
 		p.nextToken()
-		if p.peek.Type == STRING || p.peek.Type == ENTER {
+		if p.peek.Type == STRING || p.peek.Type == ENTER || p.peek.Type == TAB {
 			c := p.peek.Literal
 			p.nextToken()
 			return Command{Type: ALT, Args: c}
@@ -192,6 +211,28 @@ func (p *Parser) parseAlt() Command {
 	return Command{Type: ALT}
 }
 
+// parseShift parses a shift command.
+// A shift command takes one character and types while shift is held down.
+//
+// Shift+<char>
+// E.g.
+// Shift+A
+// Shift+Tab
+// Shift+Enter
+func (p *Parser) parseShift() Command {
+	if p.peek.Type == PLUS {
+		p.nextToken()
+		if p.peek.Type == STRING || p.peek.Type == ENTER || p.peek.Type == TAB {
+			c := p.peek.Literal
+			p.nextToken()
+			return Command{Type: SHIFT, Args: c}
+		}
+	}
+
+	p.errors = append(p.errors, NewError(p.cur, "Expected shift character, got "+p.cur.Literal))
+	return Command{Type: SHIFT}
+}
+
 // parseKeypress parses a repeatable and time adjustable keypress command.
 // A keypress command takes an optional typing speed and optional count.
 //
@@ -393,6 +434,44 @@ func (p *Parser) parseType() Command {
 	return cmd
 }
 
+// parseCopy parses a copy command
+// A copy command takes a string to the clipboard
+//
+// Copy "string"
+func (p *Parser) parseCopy() Command {
+	cmd := Command{Type: COPY}
+
+	if p.peek.Type != STRING {
+		p.errors = append(p.errors, NewError(p.peek, p.cur.Literal+" expects string"))
+	}
+	for p.peek.Type == STRING {
+		p.nextToken()
+		cmd.Args += p.cur.Literal
+
+		// If the next token is a string, add a space between them.
+		// Since tokens must be separated by a whitespace, this is most likely
+		// what the user intended.
+		//
+		// Although it is possible that there may be multiple spaces / tabs between
+		// the tokens, however if the user was intending to type multiple spaces
+		// they would need to use a string literal.
+
+		if p.peek.Type == STRING {
+			cmd.Args += " "
+		}
+	}
+	return cmd
+}
+
+// parsePaste parses paste command
+// Paste Command the string from the clipboard buffer.
+//
+// Paste
+func (p *Parser) parsePaste() Command {
+	cmd := Command{Type: PASTE}
+	return cmd
+}
+
 // parseSource parses source command.
 // Source command takes a tape path to include in current tape.
 //
@@ -468,6 +547,35 @@ func (p *Parser) parseSource() Command {
 	return cmd
 }
 
+// parseScreenshot parses screenshot command.
+// Screenshot command takes a file path for storing screenshot.
+//
+// Screenshot <path>
+func (p *Parser) parseScreenshot() Command {
+	cmd := Command{Type: SCREENSHOT}
+
+	if p.peek.Type != STRING {
+		p.errors = append(p.errors, NewError(p.cur, "Expected path after Screenshot"))
+		p.nextToken()
+		return cmd
+	}
+
+	path := p.peek.Literal
+
+	// Check if path has .png extension
+	ext := filepath.Ext(path)
+	if ext != ".png" {
+		p.errors = append(p.errors, NewError(p.peek, "Expected file with .png extension"))
+		p.nextToken()
+		return cmd
+	}
+
+	cmd.Args = path
+	p.nextToken()
+
+	return cmd
+}
+
 // Errors returns any errors that occurred during parsing.
 func (p *Parser) Errors() []ParserError {
 	return p.errors
