@@ -15,6 +15,8 @@ Backspace@0.1 5
 Backspace@.1 5
 Backspace@1 5
 Backspace@100ms 5
+Delete 2
+Insert 2
 Right 3
 Left 3
 Up@50ms
@@ -33,6 +35,8 @@ Sleep 3`
 		{Type: BACKSPACE, Options: ".1s", Args: "5"},
 		{Type: BACKSPACE, Options: "1s", Args: "5"},
 		{Type: BACKSPACE, Options: "100ms", Args: "5"},
+		{Type: DELETE, Options: "", Args: "2"},
+		{Type: INSERT, Options: "", Args: "2"},
 		{Type: RIGHT, Options: "", Args: "3"},
 		{Type: LEFT, Options: "", Args: "3"},
 		{Type: UP, Options: "50ms", Args: "1"},
@@ -134,6 +138,12 @@ func TestParseTapeFile(t *testing.T) {
 		{Type: BACKSPACE, Options: "", Args: "1"},
 		{Type: BACKSPACE, Options: "", Args: "2"},
 		{Type: BACKSPACE, Options: "1s", Args: "3"},
+		{Type: DELETE, Options: "", Args: "1"},
+		{Type: DELETE, Options: "", Args: "2"},
+		{Type: DELETE, Options: "1s", Args: "3"},
+		{Type: INSERT, Options: "", Args: "1"},
+		{Type: INSERT, Options: "", Args: "2"},
+		{Type: INSERT, Options: "1s", Args: "3"},
 		{Type: DOWN, Options: "", Args: "1"},
 		{Type: DOWN, Options: "", Args: "2"},
 		{Type: DOWN, Options: "1s", Args: "3"},
@@ -197,48 +207,73 @@ func TestParseTapeFile(t *testing.T) {
 }
 
 func TestParseCtrl(t *testing.T) {
-	t.Run("should parse with multiple modifiers", func(t *testing.T) {
-		tape := "Ctrl+Shift+Alt+C"
-		l := NewLexer(tape)
-		p := NewParser(l)
+	tests := []struct {
+		name     string
+		tape     string
+		wantArgs []string
+		wantErr  bool
+	}{
+		{
+			name:     "should parse with multiple modifiers",
+			tape:     "Ctrl+Shift+Alt+C",
+			wantArgs: []string{"Shift", "Alt", "C"},
+			wantErr:  false,
+		},
+		{
+			name:    "should not parse with out of order modifiers",
+			tape:    "Ctrl+Shift+C+Alt",
+			wantErr: true,
+		},
+		{
+			name:    "should not parse with out of order modifiers",
+			tape:    "Ctrl+Shift+C+Alt+C",
+			wantErr: true,
+		},
+		{
+			tape:    "Ctrl+Alt+Right",
+			wantErr: true,
+		},
+		{
+			name:     "Ctrl+Backspace",
+			tape:     "Ctrl+Backspace",
+			wantArgs: []string{"Backspace"},
+			wantErr:  false,
+		},
+		{
+			name:     "Ctrl+Space",
+			tape:     "Ctrl+Space",
+			wantArgs: []string{"Space"},
+			wantErr:  false,
+		},
+	}
 
-		cmd := p.parseCtrl()
+	for _, tc := range tests {
+		t.Run(tc.name, func(t *testing.T) {
+			l := NewLexer(tc.tape)
+			p := NewParser(l)
 
-		expectedArgs := []string{"Shift", "Alt", "C"}
-		args := strings.Split(cmd.Args, " ")
-
-		if len(expectedArgs) != len(args) {
-			t.Fatalf("Unable to parse args, expected args %d, got %d", len(expectedArgs), len(args))
-		}
-
-		for i, arg := range args {
-			if expectedArgs[i] != arg {
-				t.Errorf("Arg %d is wrong, expected %s, got %s", i, expectedArgs[i], arg)
+			cmd := p.parseCtrl()
+			if tc.wantErr {
+				if len(p.errors) == 0 {
+					t.Errorf("Expected to parse with errors but was success")
+				}
+				return
 			}
-		}
-	})
 
-	t.Run("should parse with errors when using unknown modifier", func(t *testing.T) {
-		tape := "Ctrl+AltRight"
-		l := NewLexer(tape)
-		p := NewParser(l)
+			if len(p.errors) > 0 {
+				t.Errorf("Expected to parse with no errors but was failure")
+			}
 
-		_ = p.parseCtrl()
+			args := strings.Split(cmd.Args, " ")
+			if len(tc.wantArgs) != len(args) {
+				t.Fatalf("Unable to parse args, expected args %d, got %d", len(tc.wantArgs), len(args))
+			}
 
-		if len(p.errors) == 0 {
-			t.Errorf("Expected to parse with errors but was success")
-		}
-	})
-
-	t.Run("should parse with errors when using keyword as modifier", func(t *testing.T) {
-		tape := "Ctrl+Backspace"
-		l := NewLexer(tape)
-		p := NewParser(l)
-
-		_ = p.parseCtrl()
-
-		if len(p.errors) == 0 {
-			t.Errorf("Expected to parse with errors but was success")
-		}
-	})
+			for i, arg := range args {
+				if tc.wantArgs[i] != arg {
+					t.Errorf("Arg %d is wrong, expected %s, got %s", i, tc.wantArgs[i], arg)
+				}
+			}
+		})
+	}
 }
